format.power_single_rate: Format method for power_single_rate class

View source: R/power_single_rate.R

format.power_single_rateR Documentation

Format method for power_single_rate class

Description

Format method for power_single_rate class

Usage

## S3 method for class 'power_single_rate'
format(x, digits = 3, ...)

Arguments

x

an R object of class power_single_rate

digits

a positive integer indicating how many significant digits are to be used for numeric x.

...

further arguments passed to or from other methods

Value

A character string with a human-readable summary of the detection power or a markdown-style table, depending on the number of rows.


ssutil documentation built on Sept. 18, 2026, 1:06 a.m.