View source: R/empirical_power_result.R
| print.empirical_power_result | R Documentation |
Nicely formats the output of an object of class empirical_power_result,
showing the power estimate, confidence interval, and number of simulations.
## S3 method for class 'empirical_power_result'
print(x, ...)
x |
An object of class "empirical_power_result". |
... |
Further arguments passed to or from other methods (ignored). |
Invisibly returns the object passed in.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.