Learn R Programming

ssutil (version 1.0.0)

empirical_power_result: Create an Empirical Power Result object

Description

Constructs an S3 object of class empirical_power_result, storing the estimated power, its confidence interval, and the number of simulations used to compute it.

Usage

empirical_power_result(x, n, conf.level = 0.95)

Value

An object of class empirical_power_result, a list with components:

  • power: Estimated power.

  • conf.low: Lower bound of confidence interval.

  • conf.high: Upper bound of confidence interval.

  • conf.level: Confidence level for the returned confidence interval.

  • nsim: Number of simulations.

Arguments

x

Number of successes

n

Number of trials.

conf.level

Confidence level for the returned confidence interval power.

Details

It is a wrap to binom.test

Examples

Run this code
result <- empirical_power_result(
  x = 10,
  n = 100,
  conf.level = 0.95
)
print(result)

Run the code above in your browser using DataLab