View source: R/power_events_rate.R
| format.power_events_rate | R Documentation |
Format method for power_events_rate class
## S3 method for class 'power_events_rate'
format(x, digits = 1, ...)
x |
an R object of class power_events_rate |
digits |
a positive integer indicating how many decimal digits are to be used to display the probability columns as percentages. |
... |
further arguments passed to or from other methods |
A character string with a markdown-style table of the probabilities of observing each event threshold, by sample size and risk.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.