View source: R/power_single_rate.R
| format.power_single_rate | R Documentation |
Format method for power_single_rate class
## S3 method for class 'power_single_rate'
format(x, digits = 3, ...)
x |
an R object of class power_single_rate |
digits |
a positive integer indicating how many significant digits are to be used for numeric x. |
... |
further arguments passed to or from other methods |
A character string with a human-readable summary of the detection power or a markdown-style table, depending on the number of rows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.