Computes the joint CDF for a multivariate standard normal distribution
with unit variances and a common correlation coefficient rho.
It is the exact functional inverse of multz:
multp(multz(q, k, rho), k, rho) == q.
Arguments
- q
Numeric. Quantile of the distribution.
- k
Integer. Number of variables in the multivariate normal distribution. Must be >= 1.
- rho
Numeric. Common correlation coefficient between variables (typically between 0 and 1).
- lower.tail
Logical. If
TRUE(default), probability is \(P(X \le q)\); ifFALSE, \(P(X > q)\). Mirrorspnorm.- seed
Optional. An object specifying if and how the random number generator should be initialized. Passed to
pmvnorm.