print.empirical_power_result: Print method for empirical_power_result
Description
Nicely formats the output of an object of class empirical_power_result,
showing the power estimate, confidence interval, and number of simulations.
Usage
# S3 method for empirical_power_result
print(x, ...)
Value
Invisibly returns the object passed in.
Arguments
- x
An object of class "empirical_power_result".
- ...
Further arguments passed to or from other methods (ignored).