prophr: Calculate Event Probability in the Experimental Group Given a...

View source: R/prophr.R

prophrR Documentation

Calculate Event Probability in the Experimental Group Given a Hazard Ratio

Description

Computes the event probability in the experimental group based on the event probability in the control group and a specified hazard ratio, assuming proportional hazards.

Usage

prophr(p0, hr)

Arguments

p0

Numeric scalar or vector. Probability of an event in the control group (between 0 and 1).

hr

Numeric scalar or vector. Hazard ratio (must be > 0). Must be the same length as p0.

Details

This is useful for sample size calculations, for example in PASS (TM), which does not automatically adjust the event rate for the experimental group.

Value

Numeric. The probability of an event in the experimental group.

Examples

prophr(0.05, 0.6)


ssutil documentation built on Sept. 18, 2026, 1:06 a.m.