| prophr | R Documentation |
Computes the event probability in the experimental group based on the event probability in the control group and a specified hazard ratio, assuming proportional hazards.
prophr(p0, hr)
p0 |
Numeric scalar or vector. Probability of an event in the control group (between 0 and 1). |
hr |
Numeric scalar or vector. Hazard ratio (must be > 0). Must be the same length as |
This is useful for sample size calculations, for example in PASS (TM), which does not automatically adjust the event rate for the experimental group.
Numeric. The probability of an event in the experimental group.
prophr(0.05, 0.6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.